from enum import Enum


class ProjectType(Enum):
    PYTHON = "python"
    JUPYTER = "jupyter"
